package fr.cnrs.mri.util.database;

import java.awt.Color;
import java.awt.Font;
import java.awt.Rectangle;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.util.Observable;
import java.util.Observer;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JTextArea;
import javax.swing.UIManager;
import javax.swing.JComboBox;

public class DatabaseLoaderView extends JFrame implements Observer{

	private DatabaseLoader model;
	private JPanel jContentPane = null;
	private JButton loadBtn;
	private JComboBox<String> databaseComboBox = null;
	private JProgressBar jProgressBar = null;
	private String buttonText;
	private static final long serialVersionUID = 1L;
	
	public DatabaseLoaderView(DatabaseLoader loadDBController) {
		super();
		this.model = loadDBController;
		this.model.addObserver(this);
		DatabaseUtil.getInstance().addObserver(this);
		initialize();
	}

	private void initialize() {
		this.setResizable(false);
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		this.setSize(439, 213);
		this.setContentPane(getJContentPane());
		this.setTitle("Load Database");
	}

	private JPanel getJContentPane() {
		if (jContentPane  == null) {
			jContentPane = new JPanel();
			jContentPane.setLayout(null);
			
			JTextArea textArea = new JTextArea("Choose the database to load");
			textArea.setBounds(12, 27, 389, 23);
			textArea.setEditable(false);
			textArea.setEnabled(false);
			textArea.setFont(new Font("Dialog", Font.BOLD, 16));
			textArea.setDisabledTextColor(Color.BLACK);
			textArea.setBackground(UIManager.getColor("Button.background"));
			jContentPane.add(textArea);
			
			jContentPane.add(this.getDatabaseComboBox(), null);
			
			jContentPane.add(this.getLoadButton(), null);
			
			jContentPane.add(this.getJProgressBar(), null);
			
			
		}
		return jContentPane;
	}

	private JButton getLoadButton() {
		if (loadBtn == null) {
			loadBtn = new JButton("Load");
			loadBtn.setBounds(160, 146, 95, 23);
			loadBtn.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					model.setSelectedDatabase((String)getDatabaseComboBox().getSelectedItem());
					model.toggleRunning();
				}
			});
		}
		return loadBtn;
	}
	
	private JComboBox<String> getDatabaseComboBox() {
		if (databaseComboBox == null) {
			databaseComboBox = new JComboBox<String>();
			databaseComboBox.setBounds(66, 74, 285, 33);
		}
		return databaseComboBox;
	}
	
	@Override
	public void update(Observable sender, Object anAspect) {
		if (anAspect.equals("selectedDatabase")) this.handleChangedDatabaseList();
		if (anAspect.equals("progress")) this.handleChangedProgress();
		if (anAspect.equals("progressMax")) this.handleChangedProgressMax();
		if (anAspect.equals("error")) this.handleChangedError();
		if (anAspect.equals("running")) this.handleChangedButton();
	}

	private void handleChangedError() {
		if (!DatabaseUtil.getInstance().getError().equals("")) {
			this.getJProgressBar().setValue(0);
			getLoadButton().setEnabled(true);
			JOptionPane.showConfirmDialog(null, DatabaseUtil.getInstance().getError(), "Error writing file!",  JOptionPane.WARNING_MESSAGE, JOptionPane.CLOSED_OPTION);
		}
	}

	private void handleChangedProgressMax() {
		this.getJProgressBar().setMinimum(0);
		this.getJProgressBar().setMaximum(DatabaseUtil.getInstance().getProgressMax());
		this.getJProgressBar().setValue(0);
	}

	private JProgressBar getJProgressBar() {
		if (jProgressBar == null) {
			jProgressBar = new JProgressBar();
			jProgressBar.setBounds(90, 119, 238, 14);
			jProgressBar.setStringPainted(true);
		}
		return jProgressBar;
	}

	private void handleChangedProgress() {
		this.getJProgressBar().setValue(DatabaseUtil.getInstance().getProgress());
		if (DatabaseUtil.getInstance().getProgress()>=DatabaseUtil.getInstance().getProgressMax()) {
			Toolkit.getDefaultToolkit().beep();
			getLoadButton().setEnabled(true);
		}
		
	}

	private void handleChangedDatabaseList() {
		JComboBox<String> cb = this.getDatabaseComboBox();
		cb.setBounds(new Rectangle(66, 74, 285, 33));
		cb.removeAllItems();
		String[] script;
		try {
			script = DatabaseLoaderConfig.getCurrent().getListOfScript().split(",");
			for (int i = 0 ; i < script.length ; i++) {
				cb.addItem(script[i]);
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		
	}
	
	private void handleChangedButton() {
		buttonText = "STOP";
		if (DatabaseUtil.getInstance().isStopped()) {
			buttonText = "Load";
		}
		this.getLoadButton().setText(buttonText);
	}
}
